#!/bin/bash
#
# icecast      Start and stop the Icecast streaming media server.
#
# chkconfig:   - 96 04
# description: Icecast is an Internet based broadcasting system.
# processname: icecast
#

# Get config.
. /etc/sysconfig/network

# Check that networking is up.
[ ${NETWORKING} = "no" ] && exit 0

# Source function library.
. /etc/init.d/functions


# See how we were called.
start() {
	# start daemon
	echo -n $"Starting Icecast streaming server: "
	daemon /usr/sbin/icecast -b -c /etc/icecast/icecast.xml
	RETVAL=$?
	[ $RETVAL -eq 0 ] && echo_success
	echo
	[ $RETVAL = 0 ] && touch /var/lock/subsys/icecast
	return $RETVAL
}

stop() {
	# stop daemon
	echo -n $"Stopping Icecast streaming server: "
	killproc icecast && rm -f /var/lock/subsys/icecast
	RETVAL=$?
	echo
	return $RETVAL
}


case "$1" in
  start)
	start
	;;
  stop)
	stop
	;;
  restart)
	stop
	start
	RETVAL=$?
	;;
  status)
	status icecast
	RETVAL=$?
	;;
  condrestart)
	if [ -f /var/lock/subsys/icecast ] ; then
		stop
		start
		RETVAL=$?
	fi
	;;
  *)
	echo $"Usage: $0 {start|stop|status|condrestart|restart}"
	RETVAL=1
	;;
esac

exit $RETVAL

